@@ -297,14 +297,14 @@ refs( int l, FILE *f, char *start, char *end, char *format)
     curlevel = list->level;
     list = list->next;		/* look at next element before going on */
 
-    if (start != NULL && list != NULL) {
+    if ((start != NULL) && (list != NULL) && (list->level > curlevel)) {
 	/* don't write start if there's no menue at all */
 	inlist = TRUE;
 	fprintf(f, "%s", start);
     }
     while (list != NULL) {
 	/* we are onto the next topic so stop */
-	if (list->level == curlevel)
+	if (list->level <= curlevel)
 	    break;
 	/* these are the next topics down the list */
 	if (list->level == curlevel + 1) {
