@@ -268,8 +268,10 @@ contour(int num_isolines, struct iso_curve *iso_lines)
 		z = eval_link_function((&Z_AXIS), z);
 	    break;
 	case LEVELS_INCREMENTAL:
-	    z = AXIS_LOG_VALUE(FIRST_Z_AXIS, contour_levels_list[0]) +
-		i * AXIS_LOG_VALUE(FIRST_Z_AXIS, contour_levels_list[1]);
+	    if (Z_AXIS.log)
+		z = contour_levels_list[0] * pow(contour_levels_list[1], (double)i);
+	    else
+		z = contour_levels_list[0] + i * contour_levels_list[1];
 	    break;
 	case LEVELS_DISCRETE:
 	    z = AXIS_LOG_VALUE(FIRST_Z_AXIS, contour_levels_list[i]);
