@@ -1,7 +1,3 @@
-#ifndef lint
-static char *RCSid() { return RCSid("$Id: eval.c,v 1.146.2.1 2017/08/09 04:43:13 sfeam Exp $"); }
-#endif
-
 /* GNUPLOT - eval.c */
 
 /*[
@@ -68,6 +64,12 @@ struct udft_entry *first_udf = NULL;
 /* pointer to first udv users can delete */
 struct udvt_entry **udv_user_head;
 
+/* Various abnormal conditions during evaluation of an action table
+ * (the stored form of an expression) are signalled by setting
+ * undefined = TRUE.
+ * NB:  A test for  "if (undefined)"  is only valid immediately
+ * following a call to evaluate_at() or eval_link_function().
+ */
 TBOOLEAN undefined;
 
 /* The stack this operates on */
@@ -311,6 +313,8 @@ imag(struct value *val)
 	/*     x = 2;  plot sprintf(format,x)         */
 	int_warn(NO_CARET, "encountered a string when expecting a number");
 	int_error(NO_CARET, "Did you try to generate a file name using dummy variable x or y?");
+    case NOTDEFINED:
+	return not_a_number();
     default:
 	int_error(NO_CARET, "unknown type in imag()");
     }
@@ -405,7 +409,7 @@ struct value *
 Gstring(struct value *a, char *s)
 {
     a->type = STRING;
-    a->v.string_val = s;
+    a->v.string_val = s ? s : strdup("");
     return (a);
 }
 
@@ -687,7 +691,12 @@ execute_at(struct at_type *at_ptr)
 void
 evaluate_at(struct at_type *at_ptr, struct value *val_ptr)
 {
+    /* A test for if (undefined) is allowed only immediately following
+     * evalute_at() or eval_link_function().  Both must clear it on entry
+     * so that the value on return reflects what really happened.
+     */
     undefined = FALSE;
+
     errno = 0;
     reset_stack();
 
@@ -715,7 +724,8 @@ evaluate_at(struct at_type *at_ptr, struct value *val_ptr)
 	 * E.g. load_one_range()
 	 */
 	val_ptr->type = NOTDEFINED;
-	int_error(NO_CARET, "evaluate_at: unsupported array operation");
+	if (!string_result_only)
+	    int_error(NO_CARET, "evaluate_at: unsupported array operation");
     }
 }
 
@@ -934,6 +944,9 @@ update_plot_bounds(void)
     fill_gpval_integer("GPVAL_TERM_XSIZE", canvas.xright+1);
     fill_gpval_integer("GPVAL_TERM_YSIZE", canvas.ytop+1);
     fill_gpval_integer("GPVAL_TERM_SCALE", term->tscale);
+    /* May be useful for debugging font problems */
+    fill_gpval_integer("GPVAL_TERM_HCHAR", term->h_char);
+    fill_gpval_integer("GPVAL_TERM_VCHAR", term->v_char);
 }
 
 /*
