@@ -1,7 +1,3 @@
-#ifndef lint
-static char *RCSid() { return RCSid("$Id: gadgets.c,v 1.137.2.3 2017/10/30 23:16:12 sfeam Exp $"); }
-#endif
-
 /* GNUPLOT - gadgets.c */
 
 /*[
@@ -246,18 +242,19 @@ clip_point(unsigned int x, unsigned int y)
  *   This routine uses the cohen & sutherland bit mapping for fast clipping -
  * see "Principles of Interactive Computer Graphics" Newman & Sproull page 65.
  */
-void
+int
 draw_clip_line(int x1, int y1, int x2, int y2)
 {
     struct termentry *t = term;
+    int state;
 
-    if (!clip_line(&x1, &y1, &x2, &y2))
-	/* clip_line() returns zero --> segment completely outside
-	 * bounding box */
-	return;
+    state = clip_line(&x1, &y1, &x2, &y2);
+    if (state != 0) {
+	(*t->move) (x1, y1);
+	(*t->vector) (x2, y2);
+    }
 
-    (*t->move) (x1, y1);
-    (*t->vector) (x2, y2);
+    return state;
 }
 
 /* Draw a contiguous line path which may be clipped. Compared to
@@ -271,16 +268,22 @@ draw_clip_polygon(int points, gpiPoint *p)
     int x1, y1, x2, y2;
     int pos1, pos2, clip_ret;
     struct termentry *t = term;
+    TBOOLEAN continuous = TRUE;
 
     if (points <= 1) 
 	return;
 
+    if (p[0].x != p[points-1].x || p[0].y != p[points-1].y)
+	continuous = FALSE;
+
     x1 = p[0].x;
     y1 = p[0].y;
     pos1 = clip_point(x1, y1);
     if (!pos1) /* move to first point if it is inside */
 	(*t->move)(x1, y1);
 
+    newpath();
+
     for (i = 1; i < points; i++) {
 	x2 = p[i].x;
 	y2 = p[i].y;
@@ -292,6 +295,9 @@ draw_clip_polygon(int points, gpiPoint *p)
 	    if (pos1) /* first vertex was recalculated, move to new start point */
 		(*t->move)(x1, y1);
 	    (*t->vector)(x2, y2);
+	} else {
+	    /* Path is not continuous; make sure closepath is not called */
+	    continuous = FALSE;
 	}
 
 	x1 = p[i].x;
@@ -305,6 +311,11 @@ draw_clip_polygon(int points, gpiPoint *p)
 	if (!(clip_ret == 0 && pos2 == 0))
 	    pos1 = pos2;
     }
+
+    /* Only call closepath if the polygon is truly closed; otherwise */
+    /* a spurious line connecting the start and end is generated.    */
+    if (continuous)
+	closepath();
 }
 
 void
@@ -317,11 +328,11 @@ draw_clip_arrow( int sx, int sy, int ex, int ey, int head)
 	head &= ~BACKHEAD;
     if (clip_point(ex,ey))
 	head &= ~END_HEAD;
-    clip_line(&sx, &sy, &ex, &ey);
 
-    /* Call terminal routine to draw the clipped arrow */
-    (*t->arrow)((unsigned int)sx, (unsigned int)sy,
-		(unsigned int)ex, (unsigned int)ey, head);
+    /* clip_line returns 0 if the whole thing is out of range */
+    if (clip_line(&sx, &sy, &ex, &ey))
+	(*t->arrow)((unsigned int)sx, (unsigned int)sy,
+		    (unsigned int)ex, (unsigned int)ey, head);
 }
 
 /* Clip the given line to drawing coords defined by BoundingBox.
@@ -427,11 +438,6 @@ clip_line(int *x1, int *y1, int *x2, int *y2)
 	    *y2 = y_intr[1];
 	}
     } else if (pos1) {		/* Only x1/y1 was out - update only it */
-	/* Nov 2010: When clip_line() and draw_clip_line() were consolidated in */
-	/* 2000, the test below was the only point of difference between them.  */
-	/* Unfortunately, the wrong version was kept. Now I change it back.     */
-	/* The effect of the wrong version (>= rather than >) was that a line   */
-	/* from ymin to ymax+eps was clipped to ymin,ymin rather than ymin,ymax */
 	if (dx * (*x2 - x_intr[0]) + dy * (*y2 - y_intr[0]) > 0) {
 	    *x1 = x_intr[0];
 	    *y1 = y_intr[0];
