@@ -1,7 +1,3 @@
-#ifndef lint
-static char *RCSid() { return RCSid("$Id: getcolor.c,v 1.39 2016/09/17 04:52:42 sfeam Exp $"); }
-#endif
-
 /* GNUPLOT - getcolor.c */
 
 /*[
@@ -39,8 +35,6 @@ static int interpolate_color_from_gray __PROTO((double, rgb_color *));
 static double get_max_dev __PROTO((rgb_color *colors, int j, double limit));
 static int is_extremum __PROTO((rgb_color left,rgb_color mid,rgb_color right));
 static void CMY_2_RGB __PROTO((rgb_color *color));
-static void CIEXYZ_2_RGB __PROTO((rgb_color *color));
-static void YIQ_2_RGB __PROTO((rgb_color *color));
 static void HSV_2_RGB __PROTO((rgb_color *color));
 
 
@@ -298,12 +292,6 @@ rgb1_from_gray(double gray, rgb_color *color)
     case C_MODEL_CMY:
 	CMY_2_RGB(color);
 	break;
-    case C_MODEL_YIQ:
-	YIQ_2_RGB(color);
-	break;
-    case C_MODEL_XYZ:
-	CIEXYZ_2_RGB(color);
-	break;
     }
 }
 
@@ -789,32 +777,6 @@ CMY_2_RGB(rgb_color *col)
     col->b = CONSTRAIN(1.0 - y);
 }
 
-static void
-CIEXYZ_2_RGB(rgb_color *col)
-{
-    double x,y,z;
-    
-    x = col->r;
-    y = col->g;
-    z = col->b;
-    col->r = CONSTRAIN( 1.9100 * x - 0.5338 * y - 0.2891 * z);
-    col->g = CONSTRAIN(-0.9844 * x + 1.9990 * y - 0.0279 * z);
-    col->b = CONSTRAIN( 0.0585 * x - 0.1187 * y - 0.9017 * z);
-}
-
-static void
-YIQ_2_RGB(rgb_color *col)
-{
-    double y,i,q;
-    
-    y = col->r;
-    i = col->g;
-    q = col->b;
-    col->r = CONSTRAIN(y - 0.956 * i + 0.621 * q);
-    col->g = CONSTRAIN(y - 0.272 * i - 0.647 * q);
-    col->b = CONSTRAIN(y - 1.105 * i - 1.702 * q);
-}
-
 static void
 HSV_2_RGB(rgb_color *col)
 {
