@@ -1,7 +1,3 @@
-#ifndef lint
-static char *RCSid() { return RCSid("$Id: internal.c,v 1.96.2.4 2017/09/25 19:59:19 sfeam Exp $"); }
-#endif
-
 /* GNUPLOT - internal.c */
 
 /*[
@@ -45,6 +41,7 @@ static char *RCSid() { return RCSid("$Id: internal.c,v 1.96.2.4 2017/09/25 19:59
 #include "datablock.h"	/* for datablock_size() */
 #include "variable.h"	/* for locale handling */
 #include "parse.h"	/* for string_result_only */
+#include "datafile.h"	/* for evaluate_inside_using */
 
 #include <math.h>
 
@@ -83,6 +80,7 @@ void
 eval_reset_after_error()
 {
     recursion_depth = 0;
+    undefined = FALSE;
 }
 
 void
@@ -1233,11 +1231,26 @@ f_strlen(union argument *arg)
     push(&result);
 }
 
+#define advance_one_utf8_char(utf8str) \
+    do { \
+	if ((*utf8str & 0x80) == 0x00) \
+	    utf8str += 1; \
+	else if ((*utf8str & 0xe0) == 0xc0) \
+	    utf8str += 2; \
+	else if ((*utf8str & 0xf0) == 0xe0) \
+	    utf8str += 3; \
+	else if ((*utf8str & 0xf8) == 0xf0) \
+	    utf8str += 4; \
+	else /* invalid utf8 sequence */ \
+	    utf8str += 1; \
+    } while (0)
+
 void
 f_strstrt(union argument *arg)
 {
     struct value needle, haystack, result;
     char *start;
+    int hit = 0;
 
     (void) arg;
     (void) pop(&needle);
@@ -1247,7 +1260,18 @@ f_strstrt(union argument *arg)
 	int_error(NO_CARET, "internal error : non-STRING argument to strstrt");
 
     start = strstr(haystack.v.string_val, needle.v.string_val);
-    (void) Ginteger(&result, (int)(start ? (start-haystack.v.string_val)+1 : 0));
+    if (start == 0) {
+	hit = -1;
+    } else if (encoding == S_ENC_UTF8) {
+	char *utfstring = haystack.v.string_val;
+	while (utfstring < start) {
+	    advance_one_utf8_char(utfstring);
+	    hit++;
+	}
+    } else {
+	hit = (start - haystack.v.string_val);
+    }
+    (void) Ginteger(&result, hit+1);
     gpfree_string(&needle);
     gpfree_string(&haystack);
     push(&result);
@@ -1487,7 +1511,8 @@ f_sprintf(union argument *arg)
 
     /* If the user has set an explicit LC_NUMERIC locale, apply it */
     /* to sprintf calls during expression evaluation.              */
-    set_numeric_locale();
+    if (!evaluate_inside_using)
+	set_numeric_locale();
 
     /* Each time we start this loop we are pointing to a % character */
     while (remaining-->0 && next_start[0] && next_start[1]) {
@@ -1495,11 +1520,18 @@ f_sprintf(union argument *arg)
 
 	/* Check for %%; print as literal and don't consume a parameter */
 	if (!strncmp(next_start,"%%",2)) {
+	    remaining++;	/* Don't consume a parameter value */
 	    next_start++;
+	    next_length = strcspn(next_start+1,"%") + 1;
+	    prev_pos = outpos - buffer;
+	    while (prev_pos + next_length >= bufsize) {
+		bufsize *= 2;
+		buffer = gp_realloc(buffer, bufsize, "f_sprintf");
+		outpos = buffer + prev_pos;
+	    }
 	    do {
 		*outpos++ = *next_start++;
 	    } while(*next_start && *next_start != '%');
-	    remaining++;
 	    continue;
 	}
 
@@ -1515,7 +1547,6 @@ f_sprintf(union argument *arg)
 	if ( spec_type != STRING && next_param->type == STRING )
 	    int_error(NO_CARET,"f_sprintf: attempt to print string value with numeric format");
 
-#ifdef HAVE_SNPRINTF
 	/* Use the format to print next arg */
 	switch(spec_type) {
 	case INTGR:
@@ -1533,22 +1564,6 @@ f_sprintf(union argument *arg)
 	default:
 	    int_error(NO_CARET,"internal error: invalid spec_type");
 	}
-#else
-	/* FIXME - this is bad; we should dummy up an snprintf equivalent */
-	switch(spec_type) {
-	case INTGR:
-	    sprintf(outpos, next_start, (int)real(next_param));
-	    break;
-	case CMPLX:
-	    sprintf(outpos, next_start, real(next_param));
-	    break;
-	case STRING:
-	    sprintf(outpos, next_start, next_param->v.string_val);
-	    break;
-	default:
-	    int_error(NO_CARET,"internal error: invalid spec_type");
-	}
-#endif
 
 	next_start[next_length] = tempchar;
 	next_start += next_length;
@@ -1593,7 +1608,8 @@ f_sprintf(union argument *arg)
 	free(args);
 
     /* Return to C locale for internal use */
-    reset_numeric_locale();
+    if (!evaluate_inside_using)
+	reset_numeric_locale();
 
 }
 
@@ -1665,7 +1681,7 @@ f_strftime(union argument *arg)
     /* Get time_str */
     length = gstrftime(buffer, buflen, fmtstr, real(&val));
     if (length == 0 || length >= buflen)
-	int_error(NO_CARET, "Resulting string is too long");
+	int_error(NO_CARET, "String produced by time format is too long");
 
     /* Remove trailing space */
     assert(buffer[length-1] == ' ');
