@@ -1,5 +1,5 @@
 /*
- * $Id: jitter.h,v 1.1 2015/09/14 03:28:47 sfeam Exp $
+ * $Id: jitter.h,v 1.0 2015/09/13 19:30:52 sfeam Exp $
  */
 #ifndef GNUPLOT_JITTER_H
 # define GNUPLOT_JITTER_H
@@ -16,7 +16,8 @@
 enum jitterstyle {
     JITTER_DEFAULT = 0,
     JITTER_SWARM,
-    JITTER_SQUARE
+    JITTER_SQUARE,
+    JITTER_ON_Y
     };
 
 typedef struct {
