@@ -1,7 +1,3 @@
-/*
- * $Id: misc.h,v 1.41 2014/04/25 00:22:23 sfeam Exp $
- */
-
 /* GNUPLOT - misc.h */
 
 /*[
@@ -43,6 +39,7 @@
 
 #include "graphics.h"
 #include "graph3d.h"
+#include "term_api.h"
 
 
 /* Variables of misc.c needed by other modules: */
@@ -107,8 +104,13 @@ typedef struct lf_state_struct {
     int c_token;		/* Which one were we on ? */
     struct lf_state_struct *prev;			/* defines a stack */
     int call_argc;		/* This saves the _caller's_ argc */
-    char *call_args[10];	/* args when file is 'call'ed instead of 'load'ed */
+    char *call_args[10];	/* ARG0 through ARG9 from "call" command */
+    struct value argv[10];	/* content of global ARGV[] array */
 }  LFS;
 extern LFS *lf_head;
 
+/* encoding stuff */
+enum set_encoding_id encoding_from_locale(void);
+void init_encoding(void);
+
 #endif /* GNUPLOT_MISC_H */
