@@ -1,7 +1,3 @@
-#ifndef lint
-static char *RCSid() { return RCSid("$Id: plot.c,v 1.174.2.1 2017/06/01 22:51:43 sfeam Exp $"); }
-#endif
-
 /* GNUPLOT - plot.c */
 
 /*[
@@ -129,9 +125,10 @@ static void wrapper_for_write_history __PROTO((void));
 
 TBOOLEAN interactive = TRUE;	/* FALSE if stdin not a terminal */
 TBOOLEAN noinputfiles = TRUE;	/* FALSE if there are script files */
-TBOOLEAN reading_from_dash=FALSE; /* True if processing "-" as an input file */
-TBOOLEAN skip_gnuplotrc = FALSE;/* skip system gnuplotrc and ~/.gnuplot */
-TBOOLEAN persist_cl = FALSE; /* TRUE if -persist is parsed in the command line */
+TBOOLEAN reading_from_dash=FALSE;	/* True if processing "-" as an input file */
+TBOOLEAN skip_gnuplotrc = FALSE;	/* skip system gnuplotrc and ~/.gnuplot */
+TBOOLEAN persist_cl = FALSE; 		/* --persist command line option */
+TBOOLEAN slow_font_startup = FALSE;	/* --slow command line option */
 
 /* user home directory */
 static const char *user_homedir = NULL;
@@ -139,7 +136,8 @@ static const char *user_homedir = NULL;
 /* user shell */
 const char *user_shell = NULL;
 
-static TBOOLEAN successful_initialization = FALSE;
+/* not static because unset.c refers to it when in debugging mode */
+TBOOLEAN successful_initialization = FALSE;
 
 #ifdef X11
 extern int X11_args __PROTO((int, char **)); /* FIXME: defined in term/x11.trm */
@@ -299,15 +297,18 @@ main(int argc, char **argv)
 #endif
 
 #if defined(OS2)
-    int rc;
+    {
+	int rc;
 #ifdef OS2_IPC
-    char semInputReadyName[40];
-    sprintf( semInputReadyName, "\\SEM32\\GP%i_Input_Ready", getpid() );
-    rc = DosCreateEventSem(semInputReadyName,&semInputReady,0,0);
-    if (rc != 0)
-      fputs("DosCreateEventSem error\n",stderr);
+	char semInputReadyName[40];
+
+	sprintf(semInputReadyName, "\\SEM32\\GP%i_Input_Ready", getpid());
+	rc = DosCreateEventSem(semInputReadyName, &semInputReady, 0, 0);
+	if (rc != 0)
+	    fputs("DosCreateEventSem error\n", stderr);
 #endif
-    rc = RexxRegisterSubcomExe("GNUPLOT", (PFN) RexxInterface, NULL);
+	rc = RexxRegisterSubcomExe("GNUPLOT", (PFN) RexxInterface, NULL);
+    }
 #endif
 
 /* malloc large blocks, otherwise problems with fragmented mem */
@@ -372,6 +373,7 @@ main(int argc, char **argv)
 		    "  -V, --version\n"
 		    "  -h, --help\n"
 		    "  -p  --persist\n"
+		    "  -s  --slow\n"
 		    "  -d  --default-settings\n"
 		    "  -c  scriptfile ARG1 ARG2 ... \n"
 		    "  -e  \"command1; command2; ...\"\n"
@@ -395,6 +397,8 @@ main(int argc, char **argv)
 #endif
 		) {
 	    persist_cl = TRUE;
+	} else if (!strncmp(argv[i], "-slow", 2) || !strcmp(argv[i], "--slow")) {
+	    slow_font_startup = TRUE;
 	} else if (!strncmp(argv[i], "-d", 2) || !strcmp(argv[i], "--default-settings")) {
 	    /* Skip local customization read from ~/.gnuplot */
 	    skip_gnuplotrc = TRUE;
@@ -623,6 +627,9 @@ RECOVER_FROM_ERROR_IN_DASH:
 		noinputfiles = FALSE;
 		do_string(*argv);
 
+	    } else if (!strncmp(*argv, "-slow", 2) || !strcmp(*argv, "--slow")) {
+		slow_font_startup = TRUE;
+
 	    } else if (!strncmp(*argv, "-d", 2) || !strcmp(*argv, "--default-settings")) {
 		/* Ignore this; it already had its effect */
 		FPRINTF((stderr, "ignoring -d\n"));
@@ -638,10 +645,11 @@ RECOVER_FROM_ERROR_IN_DASH:
 		    fprintf(stderr, "syntax:  gnuplot -c scriptname args\n");
 		    gp_exit(EXIT_FAILURE);
 		}
-		for (i=0; i<argc; i++)
+		call_argc = GPMIN(9, argc - 1);
+		for (i=0; i<=call_argc; i++) {
 		    /* Need to stash argv[i] somewhere visible to load_file() */
 		    call_args[i] = gp_strdup(argv[i+1]);
-		call_argc = argc - 1;
+		}
 
 		load_file(loadpath_fopen(*argv, "r"), gp_strdup(*argv), 5);
 		gp_exit(EXIT_SUCCESS);
