@@ -102,8 +102,15 @@ static struct udft_entry plot_func;
 
 int plot3d_num=0;
 
-/* HBB 20000508: moved these functions to the only module that uses them
- * so they can be turned 'static' */
+/* FIXME:
+ * Because this is global, it gets clobbered if there is more than
+ * one unbounded iteration in the splot command, e.g.
+ *	splot for [i=0:*] A index i, for [j=0:*] B index j
+ * Moving it into (struct surface_points) would be nice but would require
+ * extra bookkeeping to track which plot header it is stored in.
+ */
+static int last_iteration_in_first_pass = INT_MAX;
+
 /*
  * sp_alloc() allocates a surface_points structure that can hold 'num_iso_1'
  * iso-curves with 'num_samp_2' samples and 'num_iso_2' iso-curves with
@@ -1367,10 +1374,11 @@ eval_3dplots()
 /*** First Pass: Read through data files ***/
     /*
      * This pass serves to set the x/yranges and to parse the command, as
-     * well as filling in every thing except the function data. That is done
+     * well as filling in everything except the function data. That is done
      * after the x/yrange is defined.
      */
     plot_iterator = check_for_iteration();
+    last_iteration_in_first_pass = INT_MAX;
 
     while (TRUE) {
 
@@ -1568,6 +1576,9 @@ eval_3dplots()
 		this_plot->has_grid_topology = TRUE;
 		this_plot->plot_style = func_style;
 		this_plot->num_iso_read = iso_samples_2;
+		/* FIXME: additional fields may need to be reset */
+		this_plot->opt_out_of_hidden3d = FALSE;
+		this_plot->title_is_suppressed = FALSE;
 		/* ignore it for now */
 		some_functions = TRUE;
 		end_token = c_token - 1;
@@ -1865,6 +1876,14 @@ eval_3dplots()
 		    this_plot->lp_properties.p_size = 1;
 	    }
 
+	    /* FIXME: Leaving an explicit font in the label style for contour */
+	    /* labels causes a double-free segfault.  Clear it preemptively.  */
+	    if (this_plot->plot_style == LABELPOINTS
+	    &&  (draw_contour && !this_plot->opt_out_of_contours)) {
+		free(this_plot->labels->font);
+		this_plot->labels->font = NULL;
+	    }
+
 	    if (crnt_param == 0
 		&& this_plot->plot_style != PM3DSURFACE
 		/* don't increment the default line/point properties if
@@ -2005,14 +2024,16 @@ eval_3dplots()
 	    }
 
 	    SKIPPED_EMPTY_FILE:
-	    if (empty_iteration(plot_iterator))
+	    if (empty_iteration(plot_iterator) && this_plot)
 		this_plot->plot_type = NODATA;
-	    if (forever_iteration(plot_iterator) && (this_plot->plot_type == NODATA)) {
+	    if (forever_iteration(plot_iterator) && !this_plot)
+		int_error(NO_CARET, "unbounded iteration in something other than a data plot");
+	    else if (forever_iteration(plot_iterator) && (this_plot->plot_type == NODATA))
 		eof_during_iteration = TRUE;
-	    }
-	    if (forever_iteration(plot_iterator) && (this_plot->plot_type == FUNC3D)) {
-		int_error(NO_CARET, "unbounded iteration in function plot");
-	    }
+	    else if (forever_iteration(plot_iterator) && (this_plot->plot_type != DATA3D))
+		int_error(NO_CARET, "unbounded iteration in something other than a data plot");
+	    else if (forever_iteration(plot_iterator))
+		last_iteration_in_first_pass = plot_iterator->iteration_current;
 
 	    /* restore original value of sample variables */
 	    /* FIXME: sometime this_plot has changed since we save sample_var! */
@@ -2033,7 +2054,9 @@ eval_3dplots()
 
 	/* Iterate-over-plot mechanisms */
 	if (eof_during_iteration) {
-	    /* Nothing to do */ ;
+	    FPRINTF((stderr, "eof during iteration current %d\n", plot_iterator->iteration_current));
+	    FPRINTF((stderr, "    last_iteration_in_first_pass %d\n", last_iteration_in_first_pass));
+	    eof_during_iteration = FALSE;
 	} else if (next_iteration(plot_iterator)) {
 	    c_token = start_token;
 	    continue;
@@ -2043,6 +2066,9 @@ eval_3dplots()
 	if (equals(c_token, ",")) {
 	    c_token++;
 	    plot_iterator = check_for_iteration();
+	    if (forever_iteration(plot_iterator))
+		if (last_iteration_in_first_pass != INT_MAX)
+		    int_warn(NO_CARET, "splot does not support multiple unbounded iterations");
 	} else
 	    break;
 
@@ -2128,6 +2154,10 @@ eval_3dplots()
 	c_token = begin_token;
 	plot_iterator = check_for_iteration();
 
+	/* We kept track of the last productive iteration in the first pass */
+	if (forever_iteration(plot_iterator))
+	    plot_iterator->iteration_end = last_iteration_in_first_pass;
+
 	if (hidden3d) {
 	    u_step = (u_max - u_min) / (iso_samples_1 - 1);
 	    v_step = (v_max - v_min) / (iso_samples_2 - 1);
@@ -2238,6 +2268,8 @@ eval_3dplots()
 		c_token++;
 		if (crnt_param == 0)
 		    plot_iterator = check_for_iteration();
+		if (forever_iteration(plot_iterator))
+		    plot_iterator->iteration_end = last_iteration_in_first_pass;
 	    } else
 		break;
 
@@ -2329,6 +2361,8 @@ eval_3dplots()
 		continue;
 	    if (this_plot->plot_type == NODATA)
 		continue;
+	    if (this_plot->plot_type == KEYENTRY)
+		continue;
 
 	    /* Allow individual surfaces to opt out of contouring */
 	    if (this_plot->opt_out_of_contours)
@@ -2523,8 +2557,6 @@ parametric_3dfixup(struct surface_points *start_plot, int *plot_num)
 static void load_contour_label_options (struct text_label *contour_label)
 {
     struct lp_style_type *lp = &(contour_label->lp_properties);
-    if (!contour_label->font)
-	contour_label->font = gp_strdup(clabel_font);
     lp->p_interval = clabel_interval;
     lp->flags |= LP_SHOW_POINTS;
     lp_parse(lp, LP_ADHOC, TRUE);
