@@ -1,7 +1,3 @@
-#ifndef lint
-static char *RCSid() { return RCSid("$Id: pm3d.c,v 1.117.2.1 2017/10/13 19:51:45 mikulik Exp $"); }
-#endif
-
 /* GNUPLOT - pm3d.c */
 
 /*[
@@ -41,18 +37,7 @@ TBOOLEAN track_pm3d_quadrangles;
   Global options for pm3d algorithm (to be accessed by set / show).
 */
 
-pm3d_struct pm3d = {
-    "s",			/* where[6] */
-    PM3D_FLUSH_BEGIN,		/* flush */
-    0,				/* no flushing triangles */
-    PM3D_SCANS_AUTOMATIC,	/* scans direction is determined automatically */
-    PM3D_CLIP_4IN,		/* clipping: all 4 points in ranges */
-    PM3D_EXPLICIT,		/* implicit */
-    PM3D_WHICHCORNER_MEAN,	/* color from which corner(s) */
-    1,				/* interpolate along scanline */
-    1,				/* interpolate between scanlines */
-    DEFAULT_LP_STYLE_TYPE	/* for the border */
-};
+pm3d_struct pm3d;	/* Initialized via init_session->reset_command->pm3d_reset */
 
 lighting_model pm3d_shade;
 
@@ -63,10 +48,14 @@ typedef struct {
 #ifdef EXTENDED_COLOR_SPECS
     gpiPoint icorners[4];
 #endif
-    t_colorspec *border_color;	/* Only used by depthorder processing */
+    union { /* Only used by depthorder processing */
+	t_colorspec *border_color;
+	unsigned int rgb_color;
+    } qcolor;
 } quadrangle;
 
 #define PM3D_USE_BORDER_COLOR_INSTEAD_OF_GRAY -12345
+#define PM3D_USE_RGB_COLOR_INSTEAD_OF_GRAY -12346
 
 static int allocated_quadrangles = 0;
 static int current_quadrangle = 0;
@@ -396,9 +385,13 @@ void pm3d_depth_queue_flush(void)
 	double w = trans_mat[3][3];
 #endif
 	vertex out;
-	double z = 0; /* assignment keeps the compiler happy */
+	double z = 0;
+	double zbase = 0;
 	int i;
 
+	if (pm3d.base_sort)
+	    cliptorange(zbase, Z_AXIS.min, Z_AXIS.max);
+
 	for (qp = quadrangles, qe = quadrangles + current_quadrangle; qp != qe; qp++) {
 
 	    gpdPtr = qp->corners;
@@ -408,7 +401,10 @@ void pm3d_depth_queue_flush(void)
 
 	    for (i = 0; i < 4; i++, gpdPtr++) {
 
-		map3d_xyz(gpdPtr->x, gpdPtr->y, gpdPtr->z, &out);
+		if (pm3d.base_sort)
+		    map3d_xyz(gpdPtr->x, gpdPtr->y, zbase, &out);
+		else
+		    map3d_xyz(gpdPtr->x, gpdPtr->y, gpdPtr->z, &out);
 
 		if (i == 0 || out.z > z)
 		    z = out.z;
@@ -429,8 +425,10 @@ void pm3d_depth_queue_flush(void)
 
 	    /* set the color */
 	    if (qp->gray == PM3D_USE_BORDER_COLOR_INSTEAD_OF_GRAY)
-		apply_pm3dcolor(qp->border_color);
-	    else if (color_from_rgbvar || pm3d_shade.strength > 0)
+		apply_pm3dcolor(qp->qcolor.border_color);
+	    else if (qp->gray == PM3D_USE_RGB_COLOR_INSTEAD_OF_GRAY)
+		set_rgbcolor_var(qp->qcolor.rgb_color);
+	    else if (pm3d_shade.strength > 0)
 		set_rgbcolor_var((unsigned int)qp->gray);
 	    else
 		set_color(qp->gray);
@@ -469,16 +467,18 @@ pm3d_plot(struct surface_points *this_plot, int at_which_z)
     gpiPoint icorners[4];
 #endif
     gpdPoint **bl_point = NULL; /* used for bilinear interpolation */
+    TBOOLEAN color_from_column = FALSE;
+
+    /* should never happen */
+    if (this_plot == NULL)
+	return;
 
     /* just a shortcut */
-    TBOOLEAN color_from_column = this_plot->pm3d_color_from_column;
+    color_from_column = this_plot->pm3d_color_from_column;
 
     color_from_rgbvar = (this_plot->lp_properties.pm3d_color.type == TC_RGB
 			&&  this_plot->lp_properties.pm3d_color.value == -1);
 
-    if (this_plot == NULL)
-	return;
-
     /* Apply and save the user-requested line properties */
     pm3d_border_lp = this_plot->lp_properties;
     term_apply_lp_properties(&pm3d_border_lp);
@@ -573,12 +573,15 @@ pm3d_plot(struct surface_points *this_plot, int at_which_z)
 	needed_quadrangles *= (interp_i > 1) ? interp_i : 1;
 	needed_quadrangles *= (interp_j > 1) ? interp_j : 1;
 
-	while (current_quadrangle + needed_quadrangles >= allocated_quadrangles) {
-	    FPRINTF((stderr, "allocated_quadrangles = %d current = %d needed = %d\n",
-		allocated_quadrangles, current_quadrangle, needed_quadrangles));
-	    allocated_quadrangles = needed_quadrangles + 2*allocated_quadrangles;	
-	    quadrangles = (quadrangle*)gp_realloc(quadrangles, 
-			allocated_quadrangles * sizeof (quadrangle), "pm3d_plot->quadrangles");
+	if (needed_quadrangles > 0) {
+	    while (current_quadrangle + needed_quadrangles >= allocated_quadrangles) {
+		FPRINTF((stderr, "allocated_quadrangles = %d current = %d needed = %d\n",
+		    allocated_quadrangles, current_quadrangle, needed_quadrangles));
+		allocated_quadrangles = needed_quadrangles + 2*allocated_quadrangles;
+		quadrangles = (quadrangle*)gp_realloc(quadrangles,
+			    allocated_quadrangles * sizeof (quadrangle),
+			    "pm3d_plot->quadrangles");
+	    }
 	}
     }
     /* pm3d_rearrange_scan_array(this_plot, (struct iso_curve***)0, (int*)0, &scan_array, &invert); */
@@ -778,6 +781,12 @@ pm3d_plot(struct surface_points *this_plot, int at_which_z)
 		if (isnan(avgC))
 		    continue;
 
+		/* Option to not drawn quadrangles with cb out of range */
+		if (pm3d.no_clipcb && (avgC > CB_AXIS.max))
+		    continue;
+		if (pm3d.no_clipcb && (avgC < CB_AXIS.min))
+		    continue;
+
 		if (color_from_rgbvar) /* we were given an RGB color */
 			gray = avgC;
 		else /* transform z value to gray, i.e. to interval [0,1] */
@@ -852,7 +861,6 @@ pm3d_plot(struct surface_points *this_plot, int at_which_z)
 	    if (pm3d.direction == PM3D_DEPTH) {
 		/* copy quadrangle */
 		quadrangle* qp = quadrangles + current_quadrangle;
-
 		memcpy(qp->corners, corners, 4 * sizeof (gpdPoint));
 		qp->gray = gray;
 		for (i = 0; i < 4; i++) {
@@ -998,8 +1006,13 @@ pm3d_plot(struct surface_points *this_plot, int at_which_z)
 			    /* copy quadrangle */
 			    quadrangle* qp = quadrangles + current_quadrangle;
 			    memcpy(qp->corners, corners, 4 * sizeof (gpdPoint));
-			    qp->gray = gray;
-			    qp->border_color = &this_plot->lp_properties.pm3d_color;
+			    if (color_from_rgbvar) {
+				qp->gray = PM3D_USE_RGB_COLOR_INSTEAD_OF_GRAY;
+				qp->qcolor.rgb_color = (unsigned int)gray;
+			    } else {
+				qp->gray = gray;
+				qp->qcolor.border_color = &this_plot->lp_properties.pm3d_color;
+			    }
 			    current_quadrangle++;
 			} else {
 			    if (pm3d_shade.strength > 0 || color_from_rgbvar)
@@ -1021,8 +1034,13 @@ pm3d_plot(struct surface_points *this_plot, int at_which_z)
 		    /* copy quadrangle */
 		    quadrangle* qp = quadrangles + current_quadrangle;
 		    memcpy(qp->corners, corners, 4 * sizeof (gpdPoint));
-		    qp->gray = gray;
-		    qp->border_color = &this_plot->lp_properties.pm3d_color;
+		    if (color_from_rgbvar) {
+			qp->gray = PM3D_USE_RGB_COLOR_INSTEAD_OF_GRAY;
+			qp->qcolor.rgb_color = (unsigned int)gray;
+		    } else {
+			qp->gray = gray;
+			qp->qcolor.border_color = &this_plot->lp_properties.pm3d_color;
+		    }
 		    current_quadrangle++;
 		}
 	    } /* interpolate between points */
@@ -1104,13 +1122,16 @@ pm3d_reset()
     strcpy(pm3d.where, "s");
     pm3d.flush = PM3D_FLUSH_BEGIN;
     pm3d.ftriangles = 0;
-    pm3d.direction = PM3D_SCANS_AUTOMATIC;
     pm3d.clip = PM3D_CLIP_4IN;
+    pm3d.no_clipcb = FALSE;
+    pm3d.direction = PM3D_SCANS_AUTOMATIC;
     pm3d.implicit = PM3D_EXPLICIT;
     pm3d.which_corner_color = PM3D_WHICHCORNER_MEAN;
     pm3d.interp_i = 1;
     pm3d.interp_j = 1;
+    pm3d.border = default_pm3d_border;
     pm3d.border.l_type = LT_NODRAW;
+    pm3d.base_sort = FALSE;
 
     pm3d_shade.strength = 0.0;
     pm3d_shade.spec = 0.0;
@@ -1176,7 +1197,7 @@ pm3d_add_quadrangle(struct surface_points *plot, gpdPoint corners[4])
     }
     q = quadrangles + current_quadrangle++;
     memcpy(q->corners, corners, 4*sizeof(gpdPoint));
-    q->border_color = &plot->fill_properties.border_color;
+    q->qcolor.border_color = &plot->fill_properties.border_color;
     q->gray = PM3D_USE_BORDER_COLOR_INSTEAD_OF_GRAY;
 }
 
