@@ -163,6 +163,8 @@ void QtGnuplotScene::flushCurrentPointsItem()
 void QtGnuplotScene::update_key_box(const QRectF rect)
 {
 	if (m_currentPlotNumber > m_key_boxes.count()) {
+		// DEBUG Feb 2018 should no longer trigger
+		// because m_key_box insertion is done in layer code for GEAfterPlot
 		m_key_boxes.insert(m_currentPlotNumber, QtGnuplotKeybox(rect));
 	} else if (m_key_boxes[m_currentPlotNumber-1].isEmpty()) {
 		// Retain the visible/hidden flag when re-initializing the Keybox
@@ -498,6 +500,13 @@ void QtGnuplotScene::processEvent(QtGnuplotEventType type, QDataStream& in)
 			// Store it in an ordered list so we can toggle it by index
 			m_plot_group.insert(m_currentPlotNumber, newgroup);
 		} 
+
+		if (m_currentPlotNumber >= m_key_boxes.count()) {
+			QRectF empty( QPointF(0,0), QPointF(0,0));
+			m_key_boxes.insert(m_currentPlotNumber,  empty);
+			m_key_boxes[m_currentPlotNumber-1].resetStatus();
+		}
+
 		m_currentPlotNumber = 0;
 	}
 	else if (type == GEPlotNumber) 
@@ -522,7 +531,6 @@ void QtGnuplotScene::processEvent(QtGnuplotEventType type, QDataStream& in)
 		enum QtGnuplotModPlots ops = (enum QtGnuplotModPlots) ops_i;
 
 		/* FIXME: This shouldn't happen, but it does. */
-		/* Failure to reset lists after multiplot??   */
 		if (i > m_plot_group.count())
 		    i = m_plot_group.count();
 
@@ -988,9 +996,14 @@ void QtGnuplotScene::keyPressEvent(QKeyEvent* event)
 			case Qt::Key_9        : key = GP_KP_9        ; break;
 		}
 	// ASCII keys
-	else if ((event->key() <= 0xff) && (!event->text().isEmpty()))
-		// event->key() does not respect the case
-		key = event->text()[0].toLatin1();
+	else if (event->key() <= 0xff) {
+		key = event->key();
+		// the core code is supposed handle upper/lower case by
+		// inspecting the Shift modifier, but currently that does not work
+		// so instead we check here for lowercase and pass it as text.
+		if (islower((event->text()[0].toLatin1())))
+			key = event->text()[0].toLatin1();
+	}
 	// Special keys
 	else
 		switch (event->key())
@@ -1026,6 +1039,10 @@ void QtGnuplotScene::keyPressEvent(QKeyEvent* event)
 			case Qt::Key_F12        : key = GP_F12        ; break;
 		}
 
+	// The <tab> key is special.  We will catch it on keyRelease.
+	if (key == GP_Tab)
+		key = 0;
+
 	if (key >= 0)
 		live = m_eventHandler->postTermEvent(GE_keypress,
 			int(m_lastMousePos.x()), int(m_lastMousePos.y()), key, 0, m_widget);
@@ -1056,6 +1073,24 @@ void QtGnuplotScene::keyPressEvent(QKeyEvent* event)
 	QGraphicsScene::keyPressEvent(event);
 }
 
+/*
+ * Qt swallows the keyPress events from <tab> because it is used to
+ * cycle focus among a set of widgets. The documented methods for bypassing
+ * this focus-related theft are beyond my comprehension.  So instead we
+ * catch the key release event (for <tab> only) and pretend it was a press.
+ */
+void QtGnuplotScene::keyReleaseEvent(QKeyEvent* event)
+{
+	if (Qt::Key_Tab == event->key()) {
+		updateModifiers();
+		m_eventHandler->postTermEvent(GE_keypress,
+			int(m_lastMousePos.x()), int(m_lastMousePos.y()),
+			GP_Tab, 0, m_widget);
+	}
+
+	QGraphicsScene::keyReleaseEvent(event);
+}
+
 double QtGnuplotScene::sceneToGraph(int axis, double coord) const
 {
 	if (m_axisScale[axis] == 0.)
