@@ -113,6 +113,11 @@ QtGnuplotWindow::QtGnuplotWindow(int id, QtGnuplotEventHandler* eventHandler, QW
 	exportMenu->addAction(exportPngAction);
 	exportAction->setMenu(exportMenu);
 	m_toolBar->addAction(exportAction);
+	QWidget* exportWidget = m_toolBar->widgetForAction(exportAction);
+	QToolButton* exportButton = qobject_cast<QToolButton*>(exportWidget);
+	if (exportButton) {
+		connect(exportAction, SIGNAL(triggered(bool)), exportButton, SLOT(showMenu()));
+	}
 	createAction(tr("Replot")       , 'e', ":/images/replot");
 	createAction(tr("Show grid")    , 'g', ":/images/grid");
 	createAction(tr("Previous zoom"), 'p', ":/images/zoomPrevious");
@@ -153,7 +158,10 @@ void QtGnuplotWindow::on_keyAction()
 void QtGnuplotWindow::print()
 {
 	QPrinter printer;
-	if (QPrintDialog(&printer, this).exec() == QDialog::Accepted)
+	printer.setDocName(tr("gnuplot-qt graph"));
+	QPrintDialog dialog(&printer, this);
+	dialog.setOption(QAbstractPrintDialog::PrintPageRange, false);
+	if (dialog.exec() == QDialog::Accepted)
 		m_widget->print(printer);
 }
 
@@ -296,10 +304,8 @@ void QtGnuplotWindow::processEvent(QtGnuplotEventType type, QDataStream& in)
 		in >> pos;
 		move(pos);
 	}
-#ifdef _WIN32
 	else if (type == GEPID)
 		in >> m_pid;
-#endif
 	else
 		m_widget->processEvent(type, in);
 }
