@@ -201,23 +201,30 @@ static double qt_max_neg_base = 0.0;
 /* ------------------------------------------------------
  * Helpers
  * ------------------------------------------------------*/
+// Adjust for the mismatch of real coords 0->ymax and pixel coords [0:ymax-1]
+#ifndef QT_YBASE
+#define QT_YBASE 1
+#endif
 
 // Convert gnuplot coordinates into floating point term coordinates
 QPointF qt_termCoordF(int x, int y)
 {
-	return QPointF(double(x)/qt_oversamplingF, double(int(term->ymax) - y)/qt_oversamplingF);
+	return QPointF(double(x)/qt_oversamplingF,
+			double(int(term->ymax) - QT_YBASE - y)/qt_oversamplingF);
 }
 
 // The same, but with coordinates clipped to the nearest pixel
 QPoint qt_termCoord(int x, int y)
 {
-	return QPoint(qRound(double(x)/qt_oversamplingF), qRound(double(term->ymax - y)/qt_oversamplingF));
+	return QPoint(qRound(double(x)/qt_oversamplingF),
+			qRound(double(term->ymax - QT_YBASE - y)/qt_oversamplingF));
 }
 
 // Inverse of the previous function
 QPoint qt_gnuplotCoord(int x, int y)
 {
-	return QPoint(x*qt_oversampling, int(term->ymax) - y*qt_oversampling);
+	return QPoint(x*qt_oversampling,
+			int(term->ymax) - QT_YBASE - y*qt_oversampling);
 }
 
 #ifndef GNUPLOT_QT
@@ -563,6 +570,8 @@ void qt_graphics()
 	qt_sendFont();
 	term->v_tic = (unsigned int) (term->v_char/2.5);
 	term->h_tic = (unsigned int) (term->v_char/2.5);
+	// Tell user what scale factor relates term coordinates to pixels
+	term->tscale = qt_oversamplingF;
 
 	if (qt_setPosition)
 	{
@@ -740,9 +749,6 @@ void qt_put_text(unsigned int x, unsigned int y, const char* string)
 
 void qt_linetype(int lt)
 {
-	if (lt <= LT_NODRAW)
-		lt = LT_NODRAW; // background color
-
 	/* Version 5: dash pattern will be set later by term->dashtype */
 	if (lt == LT_AXIS)
 		qt->out << GEPenStyle << Qt::DotLine;
@@ -751,10 +757,9 @@ void qt_linetype(int lt)
 	else 
 		qt->out << GEPenStyle << Qt::SolidLine;
 
-	if ((lt-1) == LT_BACKGROUND) {
-		/* FIXME: Add parameter to this API to set the background color from the gnuplot end */
+	if (lt == LT_BACKGROUND)
 		qt->out << GEBackgroundColor;
-	} else
+	else if (lt > LT_NODRAW)
 		qt->out << GEPenColor << qt_colorList[lt % 9 + 3];
 }
 
