@@ -709,15 +709,14 @@ set isosamples %d, %d\n\
 	fputs("bspline\n", fp);
 	break;
     }
-    fputs("set cntrparam levels ", fp);
+    fprintf(fp, "set cntrparam levels %d\nset cntrparam levels ", contour_levels);
     switch (contour_levels_kind) {
     case LEVELS_AUTO:
-	fprintf(fp, "auto %d", contour_levels);
+	fprintf(fp, "auto");
 	break;
     case LEVELS_INCREMENTAL:
-	fprintf(fp, "incremental %g,%g,%g",
-		contour_levels_list[0], contour_levels_list[1],
-		contour_levels_list[0] + contour_levels_list[1] * contour_levels);
+	fprintf(fp, "incremental %g,%g",
+		contour_levels_list[0], contour_levels_list[1]);
 	break;
     case LEVELS_DISCRETE:
 	{
@@ -727,8 +726,8 @@ set isosamples %d, %d\n\
 		fprintf(fp, ",%g ", contour_levels_list[i]);
 	}
     }
+    fprintf(fp, "\nset cntrparam firstlinetype %d", contour_firstlinetype);
     fprintf(fp, " %ssorted\n", contour_sortlevels ? "" : "un");
-    fprintf(fp, "set cntrparam firstlinetype %d\n", contour_firstlinetype);
     fprintf(fp, "\
 set cntrparam points %d\n\
 set size ratio %g %g,%g\n\
@@ -780,7 +779,7 @@ set origin %g,%g\n",
     for (axis=0; axis<num_parallel_axes; axis++)
 	save_tics(fp, &parallel_axis[axis]);
 
-#define SAVE_AXISLABEL_OR_TITLE(name,suffix,lab)			 \
+#define SAVE_AXISLABEL_OR_TITLE(name,suffix,lab,savejust)		 \
     {									 \
 	fprintf(fp, "set %s%s \"%s\" ",					 \
 		name, suffix, lab.text ? conv_text(lab.text) : "");	 \
@@ -788,6 +787,7 @@ set origin %g,%g\n",
 	save_position(fp, &(lab.offset), 3, TRUE);			 \
 	fprintf(fp, " font \"%s\"", lab.font ? conv_text(lab.font) : "");\
 	save_textcolor(fp, &(lab.textcolor));				 \
+	if (savejust && (lab.pos != CENTRE)) save_justification(lab.pos,fp); \
 	if (lab.tag == ROTATE_IN_3D_LABEL_TAG)				 \
 	    fprintf(fp, " rotate parallel");				 \
 	else if (lab.rotate == TEXT_VERTICAL)				 \
@@ -799,11 +799,11 @@ set origin %g,%g\n",
 	fprintf(fp, "%s\n", (lab.noenhanced) ? " noenhanced" : "");	 \
     }
 
-    SAVE_AXISLABEL_OR_TITLE("", "title", title);
+    SAVE_AXISLABEL_OR_TITLE("", "title", title, TRUE);
 
     /* FIXME */
     fprintf(fp, "set timestamp %s \n", timelabel_bottom ? "bottom" : "top");
-    SAVE_AXISLABEL_OR_TITLE("", "timestamp", timelabel);
+    SAVE_AXISLABEL_OR_TITLE("", "timestamp", timelabel, FALSE);
 
     save_prange(fp, axis_array + T_AXIS);
     save_prange(fp, axis_array + U_AXIS);
@@ -811,7 +811,7 @@ set origin %g,%g\n",
 
 #define SAVE_AXISLABEL(axis)					\
     SAVE_AXISLABEL_OR_TITLE(axis_name(axis),"label",	\
-			    axis_array[axis].label)
+			    axis_array[axis].label, TRUE)
 
     SAVE_AXISLABEL(FIRST_X_AXIS);
     SAVE_AXISLABEL(SECOND_X_AXIS);
@@ -907,6 +907,12 @@ set origin %g,%g\n",
     }
     fputs("\n", fp);
 
+#if (0)
+    fprintf(fp, "set pm3d %s %s\n",
+		pm3d.clip == PM3D_CLIP_1IN ? "clip1in" : "clip4in",
+		pm3d.no_clipcb ? "noclipcb" : "");
+#endif
+
     if (pm3d_shade.strength <= 0)
 	fputs("set pm3d nolighting\n",fp);
     else
@@ -1665,8 +1671,10 @@ save_linetype(FILE *fp, lp_style_type *lp, TBOOLEAN show_point)
 	    fprintf(fp, " pointsize default");
 	else
 	    fprintf(fp, " pointsize %.3f", lp->p_size);
-	fprintf(fp, " pointinterval %d", lp->p_interval);
-	fprintf(fp, " pointnumber %d", lp->p_number);
+	if (lp->p_interval != 0)
+	    fprintf(fp, " pointinterval %d", lp->p_interval);
+	if (lp->p_number != 0)
+	    fprintf(fp, " pointnumber %d", lp->p_number);
     }
 
 }
