@@ -1,7 +1,3 @@
-#ifndef lint
-static char *RCSid() { return RCSid("$Id: show.c,v 1.385.2.3 2017/10/10 03:55:44 sfeam Exp $"); }
-#endif
-
 /* GNUPLOT - show.c */
 
 /*[
@@ -165,9 +161,7 @@ static void show_datafile __PROTO((void));
 static void show_table __PROTO((void));
 static void show_micro __PROTO((void));
 static void show_minus_sign __PROTO((void));
-#ifdef USE_MOUSE
 static void show_mouse __PROTO((void));
-#endif
 static void show_plot __PROTO((void));
 static void show_variables __PROTO((void));
 
@@ -585,11 +579,9 @@ show_command()
     case S_TABLE:
 	show_table();
 	break;
-#ifdef USE_MOUSE
     case S_MOUSE:
 	show_mouse();
 	break;
-#endif
     case S_PLOT:
 	show_plot();
 #if defined(USE_READLINE)
@@ -1360,6 +1352,11 @@ show_contour()
 		contour_format, clabel_font ? clabel_font : "");
 	fprintf(stderr, "\ton-plot labels placed at segment %d with interval %d\n",
 		clabel_start, clabel_interval);
+	if (contour_firstlinetype > 0)
+		fprintf(stderr, "\tfirst contour linetype will be %d\n", contour_firstlinetype);
+	else
+		fprintf(stderr, "\tfirst contour linetype will be chosen automatically\n");
+	fprintf(stderr, "\tcontour levels will be %ssorted\n", contour_sortlevels ? "" : "un");
     }
 }
 
@@ -1683,6 +1680,8 @@ show_grid()
     fprintf(stderr, "\n\tMinor grid drawn with");
     save_linetype(stderr, &(mgrid_lp), FALSE);
     fputc('\n', stderr);
+    if (grid_vertical_lines)
+	fprintf(stderr, "\tVertical grid lines in 3D plots\n");
     if (polar_grid_angle)
 	fprintf(stderr, "\tGrid radii drawn every %f %s\n",
 		polar_grid_angle / ang2rad,
@@ -2382,8 +2381,6 @@ show_palette()
 	case C_MODEL_RGB: fputs( "RGB\n", stderr ); break;
 	case C_MODEL_HSV: fputs( "HSV\n", stderr ); break;
 	case C_MODEL_CMY: fputs( "CMY\n", stderr ); break;
-	case C_MODEL_YIQ: fputs( "YIQ\n", stderr ); break;
-	case C_MODEL_XYZ: fputs( "XYZ\n", stderr ); break;
 	}
 	fprintf(stderr,"\tgamma is %.4g\n", sm_palette.gamma );
 	return;
@@ -2498,6 +2495,8 @@ show_pm3d()
 	fputs("at least 1 point of the quadrangle in x,y ranges\n", stderr);
     else
 	fputs( "all 4 points of the quadrangle in x,y ranges\n", stderr);
+    if (pm3d.no_clipcb)
+	fputs( "\t         quadrangles with cb < cbmin will not be drawn\n", stderr);
     if (pm3d.border.l_type == LT_NODRAW) {
 	fprintf(stderr,"\tpm3d quadrangles will have no border\n");
     } else {
@@ -2953,6 +2952,9 @@ show_xyzlabel(const char *name, const char *suffix, text_label *label)
 	fprintf(stderr, "\t%s%s is \"%s\", offset at ", name, suffix,
 	    label->text ? conv_text(label->text) : "");
 	show_position(&label->offset, 3);
+	fprintf(stderr, label->pos == LEFT ? " left justified"
+			: label->pos == RIGHT ? " right justified"
+			: "");
     } else
 	return;
 
@@ -3138,11 +3140,11 @@ show_table()
 	fprintf(stderr, "\ttable mode is off\n");
 }
 
-#ifdef USE_MOUSE
 /* process 'show mouse' command */
 static void
 show_mouse()
 {
+#ifdef USE_MOUSE
     SHOW_ALL_NL;
     if (mouse_setting.on) {
 	fprintf(stderr, "\tmouse is on\n");
@@ -3184,8 +3186,10 @@ show_mouse()
     } else {
 	fprintf(stderr, "\tmouse is off\n");
     }
+#else  /* USE_MOUSE */
+    int_warn(NO_CARET, "this copy of gnuplot has no mouse support");
+#endif /* USE_MOUSE */
 }
-#endif
 
 /* process 'show plot' command */
 static void
