@@ -1,7 +1,3 @@
-#ifndef lint
-static char *RCSid() { return RCSid("$Id: specfun.c,v 1.54 2017/01/02 05:11:24 sfeam Exp $"); }
-#endif
-
 /* GNUPLOT - specfun.c */
 
 /*[
@@ -3040,8 +3036,7 @@ double polevl(), p1evl(), sin(), cos();
 #endif
 
 int 
-airy( x, ai, aip, bi, bip )
-double x, *ai, *aip, *bi, *bip;
+airy( double x, double *ai, double *aip, double *bi, double *bip )
 {
     double z, zz, t, f, g, uf, ug, k, zeta, theta;
     int domflg;
