@@ -1,5 +1,5 @@
 /*
- * $Id: syscfg.h,v 1.62.2.2 2017/11/04 21:01:46 sfeam Exp $
+ * $Id: syscfg.h,v 1.62.2.1 2017/07/30 07:52:31 markisch Exp $
  */
 
 /* GNUPLOT - syscfg.h */
@@ -113,7 +113,9 @@
 /* Fix for broken compiler headers
  * See stdfn.h
  */
-# define S_IFIFO  _S_IFIFO
+# if !defined(__WATCOMC__) || (__WATCOMC__ <= 1290)
+#  define S_IFIFO  _S_IFIFO
+# endif
 # define HOME    "GNUPLOT"
 # define PLOTRC  "gnuplot.ini"
 # define SHELL   "\\command.com"
@@ -149,7 +151,7 @@ FILE * win_popen(const char *filename, const char *mode);
 #endif
 #endif /* _WINDOWS */
 
-#if defined(MSDOS) && !defined(_WIN32)
+#if defined(MSDOS)
 /* should this be here ? */
 # define OS       "MS-DOS"
 # undef HELPFILE
