@@ -1,5 +1,5 @@
 /*
- * $Id: tables.h,v 1.103.2.1 2017/10/10 03:55:45 sfeam Exp $
+ * $Id: tables.h,v 1.103 2017/05/20 01:27:30 sfeam Exp $
  */
 
 /* GNUPLOT - tables.h */
@@ -84,9 +84,7 @@ enum set_id {
     S_LINESTYLE, S_LINETYPE, S_LOADPATH, S_LOCALE, S_LOGSCALE, S_MACROS,
     S_MAPPING, S_MARGIN, S_LMARGIN, S_RMARGIN, S_TMARGIN, S_BMARGIN, S_MISSING,
     S_MICRO, S_MINUS_SIGN,
-#ifdef USE_MOUSE
     S_MOUSE,
-#endif
     S_MONOCHROME, S_MULTIPLOT, S_MX2TICS, S_NOMX2TICS, S_MXTICS, S_NOMXTICS,
     S_MY2TICS, S_NOMY2TICS, S_MYTICS, S_NOMYTICS,
     S_MZTICS, S_NOMZTICS, S_MRTICS,
@@ -171,7 +169,7 @@ enum set_pm3d_id {
     S_PM3D_SCANSFORWARD, S_PM3D_SCANSBACKWARD, S_PM3D_SCANS_AUTOMATIC,
     S_PM3D_DEPTH,
     S_PM3D_FLUSH, S_PM3D_FTRIANGLES, S_PM3D_NOFTRIANGLES,
-    S_PM3D_CLIP_1IN, S_PM3D_CLIP_4IN,
+    S_PM3D_CLIP_1IN, S_PM3D_CLIP_4IN, S_PM3D_CLIPCB, S_PM3D_NOCLIPCB,
     S_PM3D_MAP, S_PM3D_BORDER, S_PM3D_NOBORDER, S_PM3D_HIDDEN, S_PM3D_NOHIDDEN,
     S_PM3D_SOLID, S_PM3D_NOTRANSPARENT, S_PM3D_NOSOLID, S_PM3D_TRANSPARENT,
     S_PM3D_IMPLICIT, S_PM3D_NOEXPLICIT, S_PM3D_NOIMPLICIT, S_PM3D_EXPLICIT,
