@@ -1,7 +1,3 @@
-#ifndef lint
-static char *RCSid() { return RCSid("$Id: time.c,v 1.31.2.2 2017/09/25 19:59:19 sfeam Exp $"); }
-#endif
-
 /* GNUPLOT - time.c */
 
 /*[
@@ -78,7 +74,7 @@ static int gdysize __PROTO((int yr));
 
 static int mndday[12] = { 31, 28, 31, 30, 31, 30, 31, 31, 30, 31, 30, 31 };
 
-static size_t xstrftime __PROTO((char *buf, size_t bufsz, const char *fmt, struct tm * tm, double usec, double fulltime));
+static size_t xstrftime __PROTO((char *buf, int bsz, const char *fmt, struct tm * tm, double usec, double fulltime));
 
 /* days in year */
 static int
@@ -298,6 +294,19 @@ gstrptime(char *s, char *fmt, struct tm *tm, double *usec, double *reltime)
 		break;
 	    }
 
+	case 'a':		/* weekday name (ignored) */
+	case 'A':		/* weekday name (ignored) */
+	    while (isalpha(*s))
+		s++;
+	    break;
+	case 'w':		/* one or two digit weekday number (ignored) */
+	case 'W':		/* one or two digit week number (ignored) */
+	    if (isdigit(*s))
+		s++;
+	    if (isdigit(*s))
+		s++;
+	    break;
+
 	default:
 	    int_warn(DATAFILE, "Bad time format in string");
 	}
@@ -395,7 +404,7 @@ gstrftime(char *s, size_t bsz, const char *fmt, double l_clock)
 static size_t
 xstrftime(
     char *str,			/* output buffer */
-    size_t bsz,			/* space available */
+    int bsz,			/* remaining space available in buffer */
     const char *fmt,
     struct tm *tm,
     double usec,
@@ -406,6 +415,9 @@ xstrftime(
     char *s = str;
     TBOOLEAN sign_printed = FALSE;
 
+    if (bsz <= 0)
+	return 0;
+
     memset(str, '\0', bsz);
 
     while (*fmt != '\0') {
@@ -777,14 +789,7 @@ ggmtime(struct tm *tm, double l_clock)
 
     tm->tm_year = ZERO_YEAR;
     tm->tm_mday = tm->tm_yday = tm->tm_mon = tm->tm_hour = tm->tm_min = tm->tm_sec = 0;
-    if (l_clock < 0) {
-	while (l_clock < 0) {
-	    int days_in_year = gdysize(--tm->tm_year);
-	    l_clock += days_in_year * DAY_SEC;	/* 24*3600 */
-	    /* adding 371 is noop in modulo 7 arithmetic, but keeps wday +ve */
-	    wday += 371 - days_in_year;
-	}
-    } else {
+    if (l_clock >= 0) {
 	for (;;) {
 	    int days_in_year = gdysize(tm->tm_year);
 	    if (l_clock < days_in_year * DAY_SEC)
@@ -794,6 +799,13 @@ ggmtime(struct tm *tm, double l_clock)
 	    /* only interested in result modulo 7, but %7 is expensive */
 	    wday += (days_in_year - 364);
 	}
+    } else {
+	while (l_clock < 0) {
+	    int days_in_year = gdysize(--tm->tm_year);
+	    l_clock += days_in_year * DAY_SEC;	/* 24*3600 */
+	    /* adding 371 is noop in modulo 7 arithmetic, but keeps wday +ve */
+	    wday += 371 - days_in_year;
+	}
     }
     tm->tm_yday = (int) (l_clock / DAY_SEC);
     l_clock -= tm->tm_yday * DAY_SEC;
@@ -811,6 +823,12 @@ ggmtime(struct tm *tm, double l_clock)
     while (days >= (i = mndday[tm->tm_mon] + (tm->tm_mon == 1 && (gdysize(tm->tm_year) > 365)))) {
 	days -= i;
 	tm->tm_mon++;
+	/* This catches round-off error that initially assigned a date to year N-1 */
+	/* but counting out seconds puts it in the first second of Jan year N.     */
+	if (tm->tm_mon > 11) {
+	    tm->tm_mon = 0;
+	    tm->tm_year++;
+	}
     }
     tm->tm_mday = days + 1;
 
