@@ -1,5 +1,5 @@
 /*
- * $Id: wxt_gui.h,v 1.59 2016/10/08 16:23:05 markisch Exp $
+ * $Id: wxt_gui.h,v 1.58 2016/09/22 07:09:42 markisch Exp $
  */
 
 /* GNUPLOT - wxt_gui.h */
@@ -130,6 +130,8 @@ extern "C" {
 # include "command.h"
 /* for int_error */
 # include "util.h"
+/* for wrap_readline_signal_handler */
+# include "readline.h"
 }
 
 /* if the gtk headers are available, use them to tweak some behaviours */
