@@ -1,7 +1,7 @@
 /*
- * $Id: gnuplot_mouse.js,v 1.22.2.4 2017/05/02 20:36:32 sfeam Exp $
+ * $Id: gnuplot_mouse.js,v 1.27 2017/02/17 20:42:17 sfeam Exp $
  */
-    gnuplot.mouse_version = " 2 May 2017";
+    gnuplot.mouse_version = " 17 February 2017";
 
 // Mousing code for use with gnuplot's 'canvas' terminal driver.
 // The functions defined here assume that the javascript plot produced by
@@ -335,8 +335,15 @@ gnuplot.convert_to_polar = function (x,y)
 	r = gnuplot.plot_axis_rmin - x/Math.cos(phi);
     else
         r = gnuplot.plot_axis_rmin + x/Math.cos(phi);
-    polar.ang = phi * 180./Math.PI;
+    phi = phi * (180./Math.PI);
+    if (gnuplot.polar_sense < 0)
+	phi = -phi;
+    if (gnuplot.polar_theta0 != undefined)
+	phi = phi + gnuplot.polar_theta0;
+    if (phi > 180.)
+	phi = phi - 360.;
     polar.r = r;
+    polar.ang = phi;
     return polar;
 }
 
@@ -486,10 +493,6 @@ gnuplot.zoomXY = function(x,y)
   var zoom = new Object;
   var xreal, yreal;
 
-  // Work-around for bug in plots created prior to version 5.0.7
-  gnuplot.plot_axis_width  = gnuplot.plot_axis_xmax - gnuplot.plot_axis_xmin;
-  gnuplot.plot_axis_height = gnuplot.plot_axis_ymax - gnuplot.plot_axis_ymin;
-
   zoom.x = x; zoom.y = y; zoom.clip = false;
 
   if (gnuplot.plot_logaxis_x != 0) {
